#
# spec file for package python-zdaemon
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define modname zdaemon

Name:           python-%{modname}
Version:        4.1.0
Release:        5.2
Summary:        Daemon process control library and tools
License:        ZPL-2.1
Group:          Development/Languages/Python
Url:            https://github.com/zopefoundation/zdaemon
Source:         https://pypi.python.org/packages/source/z/zdaemon/%{modname}-%{version}.zip
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  unzip
Requires(post):  update-alternatives
Requires(postun):  update-alternatives
Requires:       python-ZConfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
zdaemon is a Python package which provides APIs for managing
applications run as daemons. Its principal use to date has been to
manage the application server and storage server daemons for Zope / ZEO,
although it is not limited to running Python-based applications

%prep
%setup -q -n %{modname}-%{version}
sed -i "s|%{modname} =|%{modname}-%{py_ver} =|" setup.py
# remove unwanted shebang
sed -i '1 { /^#!/ d }' src/zdaemon/tests/nokill.py

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
# create a dummy target for /etc/alternatives/zdaemon
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/%{modname}
ln -s -f %{_sysconfdir}/alternatives/%{modname} %{buildroot}/%{_bindir}/%{modname}

%post
update-alternatives \
    --install %{_bindir}/%{modname} %{modname} %{_bindir}/%{modname}-%{py_ver} 20

%postun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove %{modname} %{_bindir}/%{modname}-%{py_ver}
fi

%files
%defattr(-,root,root)
%doc README.rst CHANGES.rst LICENSE.txt
%ghost %{_sysconfdir}/alternatives/%{modname}
%{python_sitelib}/*
%{_bindir}/%{modname}
%{_bindir}/%{modname}-%{py_ver}

%changelog
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.1.0:
  * Add --version command line option (fixes #4).
  * kill now accepts signal names, not just numbers (#11).
  * Restore logreopen as an alias for kill USR2 (removed in version
    3.0.0 due to lack of tests): #10.
  * Make logreopen also reopen the transcript log: #9.
  * Reopen event log on logreopen or reopen_transcript: #8.
  * Help message for reopen_transcript (#5).
  * Fix race condition where stop would be ignored if the daemon
    manager was waiting before respawning a crashed program. #13.
  * Partially fix delayed deadlock when the transcript file runs
    into a full disk (#1).
  * Fix test suite leaving stale processes behind (#7).
- additional changes from version 4.0.1:
  * Add support for PyPy. (PyPy3 is pending release of a fix for:
    https://bitbucket.org/pypy/pypy/issue/1946)
  * Add support for Python 3.4.
  * Add -t/--transcript command line option.
  * zdaemon can now be invoked as a module as in python -m zdaemon
- update project URL
- update source URL, tar.gz not available
- add new build dependency unzip
- declare BuildRoot
- declare python_sitelib for SLE11
- fix update-alternatives (post, postun)
- remove unwanted shebang of nokill.py
- update package documentation and add LICENSE.txt
* Sun Feb 16 2014 os-dev@jacraig.com
- Update to 4.0.0:
  * Note / test support for Python 3.2.
- Add requirement for python-ZConfig, see setup.py.
- Update source URL, .zip not available for this version.
* Fri Feb  7 2014 p.drouand@gmail.com
- Fix wrong implementation
* Fri Feb  7 2014 p.drouand@gmail.com
- Implement update-alternative
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Apr 16 2013 p.drouand@gmail.com
- Update to version 4.0.0a1
  + Added tox support and MANIFEST.in for proper releasing.
  + Added Python 3.3 support.
  + Drop Python 2.4 and 2.5 support.
- Added url as source; add BuildRequires: unzip
  Please see http://en.opensuse.org/SourceUrls
* Mon Jan 14 2013 p.drouand@gmail.com
-Update to 3.0.5 version:
  * Fixed: the status command didn't return a non-zero exit status when
  the program wasn't running. This made it impossible for other software
  (e.g. Puppet) to tell if a process was running.
- Update to 3.0.0 version:
  * Added an option, start-test-program to supply a test command to test
    whether the program managed by zdaemon is up and operational, rather
    than just running. When starting a program, the start command doesn't
    return until the test passes. You could, for example, use this to wait
    until a web server is actually accepting connections.
  * Added a start-timeout option to error if a program takes too long to start.
    This is especially useful in combination with the start-test-program option.
  * Added an option, stop-timeout, to control how long to wait for a graceful shutdown.
  * Previously, this was controlled by backoff-limit, which didn't make much sense.
  * Several undocumented, untested, and presumably unused features were removed.
* Thu Dec  8 2011 cfarrell@suse.com
- license update: ZPL-2.1
  Simplify to ZPL-2.1
* Wed Dec  7 2011 coolo@suse.com
- most is ZPL-2.1, only one test is ZPL-2.0
* Wed Nov 10 2010 coolo@novell.com
- fix file list
* Tue Jun 22 2010 hvogel@novell.com
- Get rid if buildroot removal in install
* Wed Jun  2 2010 hvogel@novell.com
- Initial Package, Version 2.0.4
